@@ -1,6 +1,6 @@
 package Whelk::Schema::Definition::Null;
-$Whelk::Schema::Definition::Null::VERSION = '0.02';
-use Kelp::Base 'Whelk::Schema::Definition';
+$Whelk::Schema::Definition::Null::VERSION = '0.03';
+use Whelk::StrictBase 'Whelk::Schema::Definition';
 
 sub openapi_dump
 {
