@@ -1,5 +1,5 @@
 package Whelk::Wrapper::Simple;
-$Whelk::Wrapper::Simple::VERSION = '0.02';
+$Whelk::Wrapper::Simple::VERSION = '0.03';
 use Kelp::Base 'Whelk::Wrapper';
 use Kelp::Exception;
 
@@ -20,7 +20,7 @@ sub wrap_success
 sub build_response_schemas
 {
 	my ($self, $endpoint) = @_;
-	my $schema = $endpoint->response_schema;
+	my $schema = $endpoint->response;
 	my $schemas = $endpoint->response_schemas;
 
 	$schemas->{200} = $schema;
